/******************************************************************************
   ATD.c

******************************************************************************/

// Include Files
#include <MC9S12E128.h>		// Derivative information
#include <stdio.h>
#include "Datatypes.h"
#include "ATD.h"
#include "Buffers.h"
#include "SCI0.h"
#include "IO.h"



// Global Variables
word ATD_Result0;		// AC Current Sense Micro
word ATD_Result1;		// AC V In Voltage Sense Micro
word ATD_Result2;		// Input Current Sense Micro
word ATD_Result3;		// Input Voltage Sense Micro
word ATD_Result4;		// Bus Voltage Sense Micro
word ATD_Result5;		// Spare
word ATD_Result6;		// Spare
word ATD_Result7;		// Spare
//word ATD_Result8;
//word ATD_Result9;
//word ATD_Result10;
//word ATD_Result11;
//word ATD_Result12;
//word ATD_Result13;
//word ATD_Result14;
//word ATD_Result15;

BOOL InputVoltageGood = FALSE;
BOOL BusVoltageGood = FALSE;
BOOL AC_VoltagePresent = FALSE;
BOOL ErrorDetected = FALSE;
BOOL AC_Phase = FALSE;
word AC_PeakVoltage = 0;
word AC_MidPoint = 511;


/******************************************************************************
  This is the ATD Interrupt Handler. */
#pragma CODE_SEG NON_BANKED
interrupt void ATD_Int(void)
{
	if (ATDSTAT1_CCF0)
		ATD_Result0 = ATDDR0;
	if (ATDSTAT1_CCF1)
		ATD_Result1 = ATDDR1;
	if (ATDSTAT1_CCF2)
		ATD_Result2 = ATDDR2;
	if (ATDSTAT1_CCF3)
		ATD_Result3 = ATDDR3;
	if (ATDSTAT1_CCF4)
		ATD_Result4 = ATDDR4;
	if (ATDSTAT1_CCF5)
		ATD_Result5 = ATDDR5;
	if (ATDSTAT1_CCF6)
		ATD_Result6 = ATDDR6;
	if (ATDSTAT1_CCF7)
		ATD_Result7 = ATDDR7;

/*
	if (ATDSTAT2_CCF8)
		ATD_Result8 = ATDDR8;
	if (ATDSTAT2_CCF9)
		ATD_Result9 = ATDDR9;
	if (ATDSTAT2_CCF10)
		ATD_Result10 = ATDDR10;
	if (ATDSTAT2_CCF11)
		ATD_Result11 = ATDDR11;
	if (ATDSTAT2_CCF12)
		ATD_Result12 = ATDDR12;
	if (ATDSTAT2_CCF13)
		ATD_Result13 = ATDDR13;
	if (ATDSTAT2_CCF14)
		ATD_Result14 = ATDDR14;
	if (ATDSTAT2_CCF15)
		ATD_Result15 = ATDDR15;
*/
}
#pragma CODE_SEG DEFAULT


/******************************************************************************
   Initialize Analog-To-Digital converter */
void InitATD(void)
{
	ATD_Result0 = 0x0000;
	ATD_Result1 = 0x0000;
	ATD_Result2 = 0x0000;
	ATD_Result3 = 0x0000;
	ATD_Result4 = 0x0000;
	ATD_Result5 = 0x0000;
	ATD_Result6 = 0x0000;
	ATD_Result7 = 0x0000;
	//ATD_Result8 = 0x0000;
	//ATD_Result9 = 0x0000;
	//ATD_Result10 = 0x0000;
	//ATD_Result11 = 0x0000;
	//ATD_Result12 = 0x0000;
	//ATD_Result13 = 0x0000;
	//ATD_Result14 = 0x0000;
	//ATD_Result15 = 0x0000;

// ATDCTL2:********************************************************************
// Bit7: ADPU    0 = power down ATD, 1 = power up ATD
// Bit6: AFFC    0 = read ATDSTAT1 to clear flag, 1 = read result register
// Bit5: AWAI    0 = run in wait mode, 1 = halt and power down in wait mode
// Bit4: ETRIGLE 0 = external trigger on edge, 1 = external trigger on level
// Bit3: ETRIGP  0 = external trigger falling/low, 1 = rising/high
// Bit2: ETRIGE  0 = disable external trigger, 1 = enable external trigger
// Bit1: ASCIE   0 = disable ATD interrupt, 1 = enable ATD interrupt
// Bit0: ASCIF   (flag) 0 = no interrupt occurred, 1 = interrupt pending

// Power up ATD, set fast flag clearing, enable sequence complete interrupt
	ATDCTL2 = ATDCTL2_ADPU_MASK | ATDCTL2_AFFC_MASK | ATDCTL2_ASCIE_MASK;

// ATDCTL3:********************************************************************
// Bit7:         Unimplemented, reads 0
// Bit6: S8C   | Conversion Sequence Length Coding:
// Bit5: S4C   | 0 = 16, 1 = 1, ... 15 = 15 conversions per sequence
// Bit4: S2C   |
// Bit3: S1C   |
// Bit2: FIFO    0 = conversion results are sequential, 1 = conversion results wrap
// Bit1: FRZ1  | ATD Behavior in Freeze Mode (Breakpoint):
// Bit0: FRZ0  | 00 = continue conversion, 10 = convert then freeze, 11 = freeze

// Do 1 conversion sequence
	//ATDCTL3 = ATDCTL3_S1C_MASK;
// Do 2 conversion sequence
	//ATDCTL3 = ATDCTL3_S2C_MASK;
// Do 8 conversion sequence
	ATDCTL3 = ATDCTL3_S8C_MASK;

// ATDCTL4:********************************************************************
// Bit7: SRES8   0 = 10 bit resolution, 1 = 8 bit resolution
// Bit6: SMP1  | Sample Time Select:
// Bit5: SMP0  | 00 = 2, 01 = 4, 10 = 8, 11 = 16 A/D conversion clock periods
// Bit4: PRS4  | ATD Clock Prescaler:
// Bit3: PRS3  | ATD clock = (0.5 x Bus clock) / (PRS[4:0] + 1)
// Bit2: PRS2  |
// Bit1: PRS1  |
// Bit0: PRS0  |

// Divide 24MHz bus clock by 12 for a maximum ATD clock of 2MHz
	ATDCTL4 = ATDCTL4_PRS2_MASK | ATDCTL4_PRS0_MASK;

// ATDCTL5:******************************************************************
// Bit7: DJM     0 = left justified data, 1 = right justified data
// Bit6: DSGN    0 = unsigned data, 1 = signed data representation
// Bit5: SCAN    0 = single conversion, 1 = continuous conversion
// Bit4: MULT    0 = sample only one channel, 1 = sample across several channels
// Bit3: CD    | Analog Input Channel Select Code:
// Bit2: CC    | 0000 = channel 0, ... 1111 = channel 15
// Bit1: CB    |
// Bit0: CA    |

// Right justify data, select ATD channel 15, start conversion scan
  //ATDCTL5 = ATDCTL5_DJM_MASK | ATDCTL5_CD_MASK | ATDCTL5_CC_MASK | ATDCTL5_CB_MASK | ATDCTL5_CA_MASK;
// Right justify data, scan multiple, begin with channel 8, start conversion scan
  //ATDCTL5 = ATDCTL5_DJM_MASK | ATDCTL5_MULT_MASK | ATDCTL5_CD_MASK;


/* Enable digital inputs of ATD circuit */
	ATDDIEN0 = (0
				| ATDDIEN0_IEN8_MASK		// Switch 1 digital input
				| ATDDIEN0_IEN9_MASK		// Switch 2 digital input
				| ATDDIEN0_IEN10_MASK		// Switch 3 digital input
				| ATDDIEN0_IEN11_MASK		// Switch 4 digital input
				/*| ATDDIEN0_IEN12_MASK*/	// Output
				/*| ATDDIEN0_IEN13_MASK*/	// Output
				/*| ATDDIEN0_IEN14_MASK*/	// Output
				/*| ATDDIEN0_IEN15_MASK*/	// Output
				);

	ATDDIEN1 = (0
				/*| ATDDIEN1_IEN0_MASK*/	// Analog input
				/*| ATDDIEN1_IEN1_MASK*/	// Analog input
				/*| ATDDIEN1_IEN2_MASK*/	// Analog input
				/*| ATDDIEN1_IEN3_MASK*/	// Analog input
				/*| ATDDIEN1_IEN4_MASK*/	// Analog input
				/*| ATDDIEN1_IEN5_MASK*/	// Analog input
				/*| ATDDIEN1_IEN6_MASK*/	// Analog input
				/*| ATDDIEN1_IEN7_MASK*/	// Analog input
				);

}


/******************************************************************************
   Start a continuous conversion cycle */
void StartATD(void)
{
// Right justify data, scan multiple, begin with channel 0, continuous conversion scan
	ATDCTL5 = ATDCTL5_DJM_MASK | ATDCTL5_MULT_MASK | ATDCTL5_SCAN_MASK;
}

/******************************************************************************
   Stop the ATD */
void StopATD(void)
{
	// Right justify data, scan multiple, begin with channel 0, continuous conversion scan
	ATDCTL5 = ATDCTL5_DJM_MASK | ATDCTL5_MULT_MASK;
}

/******************************************************************************
   Send ATD0 through ATD4 values from RAM */
void DisplayATD(void)
{
	char* BufNum;

	/*BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"%04X,%04X,%04X,%04X,%04X\r\n",ATD_Result0,ATD_Result1,ATD_Result2,ATD_Result3,ATD_Result4);
	SCI0_PutQueue(BufNum);*/


	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"AC Current Sense:    %04X\r\n",ATD_Result0);
	SCI0_PutQueue(BufNum);

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"AC Voltage Sense:    %04X\r\n",ATD_Result1);
	SCI0_PutQueue(BufNum);

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"Input Current Sense: %04X\r\n",ATD_Result2);
	SCI0_PutQueue(BufNum);

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"Input Voltage Sense: %04X\r\n",ATD_Result3);
	SCI0_PutQueue(BufNum);

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"Bus Voltage Sense:   %04X\r\n",ATD_Result4);
	SCI0_PutQueue(BufNum);
}

/******************************************************************************
   Send IO Values of Port AD */
void ReadPortAD(void)
{
	char* BufNum;

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"n%04X\r\n",PTIAD);
	SCI0_PutQueue(BufNum);
}

/******************************************************************************
   Monitor DC.
   Call this function in the main loop. */
void MonitorDC(void)
{
	// Input voltage has to be between 160 and 400
/*	if (ATD_Result3 > 410)		// Input voltage high enough
	{
		InputVoltageGood = TRUE;
	} else
	{
		InputVoltageGood = FALSE;
	}  */

	if (ATD_Result3 > 255)		// Input voltage high enough. Try 100 Volts
	{
		InputVoltageGood = TRUE;
	}

	if ((InputVoltageGood == TRUE) && (ATD_Result3 < 200))	// Try 78 Volts
	{
		InputVoltageGood = FALSE;
	}

	if (ATD_Result3 > 1020)		// Input voltage too high. Try 398 Volts
	{
		ErrorDetected = TRUE;
	}



	// Bus voltage should be between 350 and 400
	if (ATD_Result4 > 972)		// Bus voltage high enough. Try 380 Volts
	{
		BusVoltageGood = TRUE;
	}

	if ((BusVoltageGood == TRUE) && (ATD_Result4 < 869))	// Bus voltage below 340
	{
		BusVoltageGood = FALSE;
	}

	if (ATD_Result4 > 1022)		// Bus voltage higher than 400 Volts
	{
		ErrorDetected = TRUE;
	}

	if ((ErrorDetected) && (ATD_Result3 < 767) && (ATD_Result4 < 860))
	{
		ErrorDetected = FALSE;
	}

}

/******************************************************************************
   Monitor AC.
   Call this function in the main loop. */
void MonitorAC(void)
{
	if (ATD_Result1 > AC_MidPoint)
	{
		AC_Phase = TRUE;
		//AC_RelayOn();		// DIAGNOSTIC ONLY
	} else
	{
		AC_Phase = FALSE;
		//AC_RelayOff();		// DIAGNOSTIC ONLY
	}

	if (ATD_Result1 > AC_PeakVoltage)
	{
		AC_PeakVoltage = ATD_Result1;
	}
}

/******************************************************************************
   Display AC peak voltage */
void DisplayACPeakVoltage(void)
{
	char* BufNum;


	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"AC Peak Voltage: %04X\r\n",AC_PeakVoltage);
	SCI0_PutQueue(BufNum);
}

/******************************************************************************
   Display AC Mid Point */
void DisplayACMidPoint(void)
{
	char* BufNum;


	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"AC Mid Point: %04X\r\n",AC_MidPoint);
	SCI0_PutQueue(BufNum);
}

/******************************************************************************
   Display DC Voltages */
void DisplayDCVoltages(void)
{
	char* BufNum;
	float InputVoltage;
	float BusVoltage;

	InputVoltage = ((ATD_Result3 * 400.0) / 1023);

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"Input Voltage: %e\r\n",InputVoltage);
	SCI0_PutQueue(BufNum);

	BusVoltage = ((ATD_Result4 * 400.0) / 1023);

	BufNum = GetBuffer();	// Get a free buffer
	(void)sprintf(BufNum,"Bus Voltage: %e\r\n",BusVoltage);
	SCI0_PutQueue(BufNum);
}





