/******************************************************************************
   DAC.c
   Driver for the digital to analog converters. There are 2 DACs in this
   microcontroller. DAC0 is used to offset the input voltage of the AC op-amps.
   DAC1 is used for the LCD contrast control.
******************************************************************************/
#include <MC9S12E128.h>		// Derivative information
#include <stdio.h>
#include "DAC.h"
#include "Buffers.h"
#include "SCI0.h"


// Global Variables





/*****************************************************************************/
void InitDAC0(void)
{
// DAC0 Control Register 0:
// Bit0: DAC0_DACC0_DACOE       0 = output not available, 1 = output on DA0 pin
// Bit1: DAC0_DACC0_DACWAI      0 = DAC enabled in wait mode, 1 = DAC disabled in wait mode
// Bit2: DAC0_DACC0_DSGN        0 = unsigned data, 1 = signed data representation
// Bit3: DAC0_DACC0_DJM         0 = left justified data, 1 = right justified data
// Bit4:                        Unimplemented, reads 0
// Bit5:                        Unimplemented, reads 0
// Bit6: DAC0_DACC0_DACTE       Used for factory test
// Bit7: DAC0_DACC0_DACE        0 = DAC disabled & powered down, 1 = DAC enabled

// Enable DAC0, output on DA0 pin
	DAC0_DACC0 = DAC0_DACC0_DACE_MASK | DAC0_DACC0_DACOE_MASK;

// Set initial output value for AC offset - Left Justified
	DAC0_DACDLeft = 128;
}

/*****************************************************************************/
void IncrementDAC0(void)
{
	if (DAC0_DACDLeft < 255)
		DAC0_DACDLeft++;
}

/*****************************************************************************/
void DecrementDAC0(void)
{
	if (DAC0_DACDLeft > 0)
		DAC0_DACDLeft--;
}

/*****************************************************************************/
void DisplayDAC0(void)
{
	char* BufNum;

	BufNum = GetBuffer();		// Get a free buffer
	(void)sprintf(BufNum,"DAC0: %d\r\n",DAC0_DACDLeft);
	SCI0_PutQueue(BufNum);
}

/*****************************************************************************/
void InitDAC1(void)
{
// Enable DAC1, output on DA1 pin
	DAC1_DACC0 = DAC1_DACC0_DACE_MASK | DAC1_DACC0_DACOE_MASK;

// Set initial output value for LCD contrast - Left Justified
	DAC1_DACDLeft = 20;
}

/*****************************************************************************/
void IncrementDAC1(void)
{
	if (DAC1_DACDLeft < 255)
		DAC1_DACDLeft++;
}

/*****************************************************************************/
void DecrementDAC1(void)
{
	if (DAC1_DACDLeft > 0)
		DAC1_DACDLeft--;
}

/*****************************************************************************/
void DisplayDAC1(void)
{
	char* BufNum;

	BufNum = GetBuffer();		// Get a free buffer
	(void)sprintf(BufNum,"DAC1: %d\r\n",DAC1_DACDLeft);
	SCI0_PutQueue(BufNum);
}

