/******************************************************************************
   PMF.h

******************************************************************************/

#ifndef PMF_H
#define PMF_H


// Defines



/* A common crystal frequency for this microcontroller is 8MHz. The PLL multiplies
   this frequency by 3 resulting in a bus frequency of 24MHz. The PMF pre-scaler 
   is set to divide the bus frequency by 2 resulting in 12MHz being applied to
   the PMF.
   
   125 values are fetched from the sine table for eack 1/4 cycle. The table is
   referenced from 0 to 124 in the first 90 degrees of the sine wave. Then the
   table is read out from 125 to 1 for the part of the sine wave 90 to 180 degrees.
   The negative portion of the sine wave uses values 0 to 124 of the sine table
   for 180 to 270 degrees and then values 125 to 1 for 270 to 360 degrees. This
   sums up to 500 PWM pulses for one sine wave. */
   
/* For a 60 Hz system:
   PWM frequency = 500 pulses x 60 Hz = 30,000 Hz
   Prescaler frequency = Bus clock / 2 = 24,000,000 / 2 = 12,000,000 Hz
   Modulo counter = Prescaler / PWM frequency = 12,000,000 / 30,000 = 400 */   

/* For a 50 Hz system:
   PWM frequency = 500 pulses x 50 Hz = 25,000 Hz
   Prescaler frequency = 12,000,000 Hz as above
   Modulo counter = Prescaler / PWM frequency = 12,000,000 / 25,000 = 480 */


#define Modulus 400


// Function Prototypes
void InitPMF(void);
void IncAmplitude(void);
void DecAmplitude(void);
void DisplayAmplitude(void);
void EnableHBridge(void);
void DisableHBridge(void);

#endif