/******************************************************************************
   SPI.c
   Interrupt driven SPI routines.
******************************************************************************/

// Include Files
#include <MC9S12E128.h>
#include "SPI.h"


// Global Variables
byte *XPtr;		// Points to transmit buffer
byte *RPtr;		// Points to receive buffer
byte XCnt;		// Transmitter byte count
byte RCnt;		// Receiver byte count

/******************************************************************************
  This is the SPI Interrupt Handler. */
#pragma CODE_SEG NON_BANKED
interrupt void SPI_Int(void)
{
	if (SPISR_SPTEF)			// Read SPISR, check for transmitter empty flag
	{
		PTS_PTS7 = 0;			// Enable \SS
		SPIDR = *XPtr++;		// Send data byte and update pointer
		if (--XCnt == 0)
			SPICR1_SPTIE = 0;	// Disable SPI transmitter interrupts
	}
	else if (SPISR_SPIF)		// Read SPISR, check for receiver full flag
	{
		*RPtr++ = SPIDR;		// Save received byte and update pointer
		if (--RCnt == 0)		// If end of message
		{
			SPICR1_SPIE = 0;	// Disable SPI receiver interrupts
			SPICR1_SPE = 0;		// Turn off SPI circuit
			PTS_PTS7 = 1;		// Disable \SS
		}
	}
}
#pragma CODE_SEG DEFAULT

/******************************************************************************
  Initialize the SPI */
void InitSPI(void)
{
	DDRU_DDRU0 = 0;		// PortU bit 0 is an input

	PTS_PTS5 = 0;		// This port pin will be MOSI
	PTS_PTS6 = 0;		// This port pin will be SCK
	PTS_PTS7 = 1;		// This port pin will be \SS

// Enable port pin outputs to above values
	DDRS = DDRS_DDRS5_MASK|DDRS_DDRS6_MASK|DDRS_DDRS7_MASK;

// Set baud rate divisor to 640
	SPIBR = SPIBR_SPPR2_MASK|SPIBR_SPR2_MASK|SPIBR_SPR1_MASK;

// Enable SPI in Master mode
	SPICR1 = SPICR1_SPE_MASK | SPICR1_MSTR_MASK;

// Change following if other output modes required
	SPICR1_CPOL = 1;
	SPICR1_CPHA = 0;
}

/******************************************************************************
  Start the SPI */
byte SPI_Send_Bin(byte * Xmt, byte * Rcv, byte Cnt)
{
	if (!SPICR1_SPIE)	// If not already busy
	{
		XPtr = Xmt;		// Save pointer to transmit buffer
		RPtr = Rcv;		// Save pointer to receive buffer
		XCnt = Cnt;		// Save transmitter byte count
		RCnt = Cnt;		// Save receiver byte count

		SPICR1_SPE = 1;	// Turn on SPI circuit

// Start SPI transmitter and receiver interrupts
		SPICR1 |= SPICR1_SPIE_MASK + SPICR1_SPTIE_MASK;
		return 1;
	}
	else
	{
		return 0;    // SPI already busy
	}
}


